import autobahn from 'autobahn';

let instance = null;
let _connection = null;
let _session = null;
let _messageId = 1;

class CrossbarService {

    constructor() {
        if (!instance) {
            instance = this;
        }

        return instance;
    }

    connect(url, realm, user, key) {
        _connection = new autobahn.Connection({
            url: url,
            realm: realm,
            max_retries: -1,
            authid: user,
            authmethods: ["wampcra"],
            onchallenge: (session, method, extra) => {
                return this.onChallenge(session, method, extra, key);
            },
            tlsConfiguration: {}
        });

        _connection.onopen = (session) => {
            console.log("---- Authobahn connection opened ----");
            _session = session;
        };

        _connection.onclose = function (reason) {
            console.warn("---- Authobahn connection closed ----");
            console.log(reason);
        };

        _connection.open();
    }

    close() {
        if (_connection) {
            _connection.close();
            _connection = null;
            console.warn('---- Crossbar connection closed ----');
        }
    }

    publish(command, params) {
        if (_session === null) {
            setTimeout(() => {
                this.publish(command, params);
            }, 1000);
        } else {
            params = params || {};
            params.messageId = String(_session.id).slice(-4) + ":" + _messageId++;
            console.log("CB >> MSG " + params.messageId, command, params);
            _session.publish(command, [], params, {exclude_me: true});
        }
    }

    subscribe(command, func) {
        if (_session === null) {
            setTimeout(() => {
                this.subscribe(command, func);
            }, 1000);
        } else {
            _session.subscribe(command, function (args, kwargs) {
                func(args, kwargs);
            });
        }
    }

    onChallenge(session, method, extra, key) {
        if (method === "wampcra") {
            return autobahn.auth_cra.sign(key, extra.challenge);
        } else {
            throw "don't know how to authenticate using '" + method + "'";
        }
    }
}

export default new CrossbarService();
