import OcuService from "../OcuService";

class CustomersService {

    constructor() {
        this.api = window.env.API;
    }

    getCustomerVisits() {
        return OcuService.doApiCall(
            "get",
            `${this.api}/visits`,
            {},
            "get customer visits"
        );
    }

    getCustomerVisitsAccepted() {
        return OcuService.doApiCall(
            "get",
            `${this.api}/visits/accepted`,
            {},
            "get accepted visits"
        );
    }

    getCustomerVisit(visitId) {
        return OcuService.doApiCall(
            "get",
            `${this.api}/visits/${visitId}`,
            {},
            "get customer visit"
        );
    }

    getArchivedVisit(visitId) {
        return OcuService.doApiCall(
            "get",
            `${this.api}/visits/archive/${visitId}`,
            {},
            "get archived visit"
        );
    }

    getHandledCustomerVisits() {
        return OcuService.doApiCall(
            "get",
            `${this.api}/visits/handled`,
            {},
            "get handled customer visits"
        );
    }

    createCustomerVisit(visitData) {
        return OcuService.doApiCall(
            "post",
            `${this.api}/visits`,
            {},
            visitData
        );
    }

    updateCustomerVisit(visitId, visitData) {
        return OcuService.doApiCall(
            "put",
            `${this.api}/visits/${visitId}`,
            {},
            visitData
        );
    }

    updateTimeslot(data) {
        return OcuService.doApiCall(
            "put",
            `${this.api}/visits/timeslot`,
            'update timeslot',
            data
        );
    }

    deleteCustomerVisit(visitId) {
        return OcuService.doApiCall(
            "delete",
            `${this.api}/visits/${visitId}`,
            {},
            "delete customer visit"
        );
    }

    acceptCustomerVisit(visitId) {
        return OcuService.doApiCall(
            "put",
            `${this.api}/visits/${visitId}/accept`,
            {},
            "accept customer visit"
        );
    }

    refuseCustomerVisit(visitId) {
        return OcuService.doApiCall(
            "put",
            `${this.api}/visits/${visitId}/refuse`,
            {},
            "refuse customer visit"
        );
    }

    cancelCustomerVisit(visitId) {
        return OcuService.doApiCall(
            "put",
            `${this.api}/visits/${visitId}/cancel`,
            "cancel customer visit",
            {}
        );
    }

    uploadFloorplanCustomerVisit(visitId, file) {
        return OcuService.doApiCall(
            "post",
            `${this.api}/visits/${visitId}/floorplan`,
            {},
            file
        );
    }

    copyFloorplanCustomerVisit(visitId, originalId) {
        return OcuService.doApiCall(
            "post",
            `${this.api}/visits/${visitId}/floorplan/${originalId}`,
            {},
            "copy customer visit floorplan"
        );
    }

    deleteFloorPlanCustomerVisit(visitId, floorPlanId) {
        return OcuService.doApiCall(
            "delete",
            `${this.api}/visits/${visitId}/floorplan/${floorPlanId}`,
            {},
            "delete customer floorplan"
        );
    }

    getCustomerVisitOffers(visitId) {
        return OcuService.doApiCall(
            "get",
            `${this.api}/visits/${visitId}/offers`,
            {},
            "get customer visit offers"
        );
    }

    updateOffer(offerId, offerData) {
        return OcuService.doApiCall(
            "put",
            `${this.api}/offers/${offerId}`,
            {},
            offerData
        );
    }

    uploadOfferFile(offerId, file) {
        return OcuService.doApiCall(
            "post",
            `${this.api}/offers/${offerId}/upload`,
            {},
            file
        );
    }

    exportOfferExcel(offerId) {
        return OcuService.doApiCall(
            "post",
            `${this.api}/offers/${offerId}/export`,
            {}
        );
    }

    exportBom(offerId, mode) {
        return OcuService.doApiCall(
            "post",
            `${this.api}/offers/${offerId}/exportBom`,
            `create ${mode} bom export`,
            {mode: mode}
        );
    }

    exportA3(offerId) {
        return OcuService.doApiCall(
            "post",
            `${this.api}/offers/${offerId}/exportLightplan`,
            `create  a3 export`,
            {}
        );
    }

    exportOfferPdf(data) {
        return OcuService.doApiCall(
            "post",
            `${this.api}/offers/${data.id}/exportPdf`,
            'exportPDF',
            data
        );
    }

    getCustomerVisitArchive() {
        return OcuService.doApiCall(
            "get",
            `${this.api}/visits/archive`,
            {},
            "get customer visit archive"
        );
    }

    setCustomerVisitHandled(visitId) {
        return OcuService.doApiCall(
            "put",
            `${this.api}/visits/${visitId}/handle`,
            {},
            "set customer visit handled"
        );
    }

    setCustomerVisitUnHandled(visitId) {
        return OcuService.doApiCall(
            "put",
            `${this.api}/visits/${visitId}/unHandle`,
            {},
            "set customer visit handled"
        );
    }

    restoreArchived(visitId) {
        return OcuService.doApiCall(
            "post",
            `${this.api}/visits/restore`,
            {},
            {id: visitId}
        );
    }

    forceDeleteVisit(visitId) {
        return OcuService.doApiCall(
            "delete",
            `${this.api}/visits/${visitId}/force`,
            {},
            "force delete visit"
        );
    }

    replanVisit({visitId, data}) {
        return OcuService.doApiCall(
            "post",
            `${this.api}/visits/${visitId}/replan`,
            "replan visit",
            data,
        );
    }

    getCustomerFavorites(visitId) {
        return OcuService.doApiCall(
            "get",
            `${this.api}/visits/${visitId}/favorites`,
            {},
            "get customer favorites"
        );
    }

    getOfferPdf(offerId) {
        return OcuService.doExcelCall('get', `${this.api}/exports/${offerId}/download`);
    }

    getStatus(id) {
        return OcuService.doApiCall('get', `${this.api}/jobs/${id}/status`);
    }

    getExport(id) {
        return OcuService.doApiCall('get', `${this.api}/exports/${id}`);
    }

    getVisitsAsEvents(id) {
        return OcuService.doApiCall('get', `${this.api}/stores/${id}/events`, 'get events');
    }

    getStoreUsers({storeId}) {
        return OcuService.doApiCall('get', `${this.api}/stores/${storeId}/users`, 'get correct users', {});
    }

    duplicateVisit({visitId}) {
        return OcuService.doApiCall('put', `${this.api}/visits/${visitId}/duplicate`, 'duplicate visit');
    }

    sendUpdate({visitId}) {
        return OcuService.doApiCall('post', `${this.api}/visits/${visitId}/update`, 'send update mail');
    }

    uploadReference({page, data}) {
        return OcuService.doApiCall('post', `${this.api}/references/${page}/update`, 'update reference image', data);
    }

    clearAttribute({page, data}) {
        return OcuService.doApiCall('put', `${this.api}/references/${page}`, 'clear reference image attribute', data);
    }

    addReferencePage({projectId, pageTypeId}) {
        return OcuService.doApiCall(
            'post', `${this.api}/visits/${projectId}/references/pages/add`,
            'add reference page',
            {pageTypeId}
        );
    }

    swapReferencePages({projectId, ids}) {
        return OcuService.doApiCall(
            'post', `${this.api}/visits/${projectId}/references/pages/swap`,
            'swap reference page positions',
            {ids}
        );
    }

    updateReferencePageType({projectId, pageId, pageTypeId}) {
        return OcuService.doApiCall(
            'post', `${this.api}/visits/${projectId}/references/pages/updateType`,
            'swap reference page positions',
            {pageId, pageTypeId}
        );
    }

    saveReferencePageText({projectId, pageId, text}) {
        return OcuService.doApiCall(
            'post', `${this.api}/visits/${projectId}/references/pages/text`,
            'Save text on reference page',
            {pageId, text}
        );
    }

    getPageTypes() {
        return OcuService.doApiCall('get', `${this.api}/references/types`, 'get page types');
    }

    deleteReferencePage({pageId}) {
        return OcuService.doApiCall('delete', `${this.api}/references/${pageId}`, 'delete page');
    }

}

export default new CustomersService();
