import OcuService from '../OcuService'

class ProductsService {

    getProducts(page) {
        let ep = page ? window.env.API + '/products' + '?page[number]=' + page : window.env.API + '/products';
        return OcuService.doApiCall('get', ep, {}, 'get products');
    }

    getProduct(productId) {
        return OcuService.doApiCall('get', `${window.env.API}/products/${productId}`, {}, 'get product');
    }

    createProduct(productData) {
        return OcuService.doApiCall('put', `${window.env.API}/products`, productData, 'create product');
    }

    updateProduct(productId, data) {
        return OcuService.doApiCall('put', `${window.env.API}/products/${productId}`, {}, data);
    }

    deleteProduct(productId) {
        return OcuService.doApiCall('delete', `${window.env.API}/products/${productId}`, {}, 'delete product');
    }

    getFacets({language = 'nl', data = {}} = {}) {
        return OcuService.doApiCall('post', `${window.env.API}/facets?language=${language}`, 'get facets', data);
    }

    getSuggestions(data) {
        return OcuService.doApiCall('post', `${window.env.API}/products/search/suggestions`, 'get suggestions', data);
    }

    getFilteredProducts(data, page, amount) {
        const sizeParam = page ? `page[number]=${page}&` : '';
        const uri = `${window.env.API}/products/search?${sizeParam}page[size]=${amount}`;
        return OcuService.doApiCall('post', uri, 'get filtered products', data);
    }

    uploadProductFile(productId, file) {
        return OcuService.doApiCall('post', `${window.env.API}/products/${productId}/assets`, {}, file);
    }

    deleteProductFile(productId, productAssetId) {
        return OcuService.doApiCall('delete', `${window.env.API}/products/${productId}/assets/${productAssetId}`, {}, 'delete productassets');
    }

    getRFIDCodes() {
        return OcuService.doApiCall('get', `${window.env.API}/tags`, {}, 'get tags');
    }

    getRFID(tagId) {
        return OcuService.doApiCall('get', `${window.env.API}/tags/${tagId}`, {}, 'get tag');
    }

    uploadAmbience(productId, file) {
        return OcuService.doApiCall(
            "post",
            `${window.env.API}/products/${productId}/ambiences`,
            {},
            file
        );
    }

    deleteAmbienceProduct(productId, ambienceId) {
        return OcuService.doApiCall(
            "delete",
            `${window.env.API}/products/${productId}/ambiences/${ambienceId}`,
            {}
        )
    }

    updateAmbiencesProduct(productId, ambienceData) {
        return OcuService.doApiCall(
            'put',
            `${window.env.API}/products/${productId}/ambiences`,
            'update ambiences',
            ambienceData
        )
    }

    addImagesToProduct(productId, images) {
        return OcuService.doApiCall('post', `${window.env.API}/products/${productId}/ambiences/add`, 'add images to product', {images});
    }
}

export default new ProductsService();
