import OcuService from '../OcuService'

class DeviceService {

    /*Devices*/
    getDevices() {
        return OcuService.doApiCall('get', window.env.API + '/devices');
    }

    createDevice(device) {
        return OcuService.doApiCall('put', window.env.API + '/devices', 'createDevice', device)
    }

    getDevice(deviceID) {
        return OcuService.doApiCall('get', window.env.API + '/devices/' + deviceID);
    }

    updateDevice(deviceID, device) {
        return OcuService.doApiCall('post', window.env.API + '/devices/' + deviceID, 'updateDevice', device);
    }

    deleteDevice(deviceID) {
        return OcuService.doApiCall('delete', window.env.API + '/devices/' + deviceID, 'deleteDevice');
    }

    previewDevice(deviceID) {
        return OcuService.doApiCall('post', window.env.API + '/devices/' + deviceID + '/preview', 'previewDevice');
    }

    getDeviceGroupsForDevice(deviceId) {
        return OcuService.doApiCall('get', window.env.API + '/devices/' + deviceId + '/devicegroups');
    }

    /*Device Types*/
    getDeviceTypes() {
        return OcuService.doApiCall('get', window.env.API + '/devicetypes');
    }

    getDeviceType(deviceTypeID) {
        return OcuService.doApiCall('get', window.env.API + '/devicetypes/' + deviceTypeID);
    }

    getPresetsForDeviceType(deviceTypeId){
        return OcuService.doApiCall('get',window.env.API + '/devicetypes/'+deviceTypeId +'/presets');
    }

    /*Device Groups*/
    getDeviceGroups() {
        return OcuService.doApiCall('get', window.env.API + '/devicegroups');
    }

    createDeviceGroup(deviceGroup) {
        return OcuService.doApiCall('put', window.env.API + '/devicegroups', 'createDeviceGroup', deviceGroup)
    }

    getDeviceGroup(deviceGroupID) {
        return OcuService.doApiCall('get', window.env.API + '/devicegroups/' + deviceGroupID);
    }

    updateDeviceGroup(deviceGroupID, deviceGroup) {
        return OcuService.doApiCall('post', window.env.API + '/devicegroups/' + deviceGroupID, 'updateDeviceGroup', deviceGroup);
    }

    deleteDeviceGroup(deviceGroupID) {
        return OcuService.doApiCall('delete', window.env.API + '/devicegroups/' + deviceGroupID, 'deleteDeviceGroup');
    }

    getDevicesInDeviceGroup(deviceGroupID) {
        return OcuService.doApiCall('get', window.env.API + '/devicegroups/' + deviceGroupID + '/devices');
    }

    syncDevicesInDevicegroup(deviceGroupId){
        return OcuService.doApiCall('post', window.env.API +'/devicegroups/'+deviceGroupId+'/devices', 'syncDevices');
    }


    /*Deployments*/
    createDeployment(data) {
        return OcuService.doApiCall('put', window.env.API +'/deployments','createDeployment', data);
    }

    getDeployment(deploymentId) {
        return OcuService.doApiCall('get', window.env.API + '/deployments/' + deploymentId);
    }

    updateDeployment(deploymentData, deploymentId) {
        return OcuService.doApiCall('post',window.env.API + '/deployments/' + deploymentId ,'updateDeployment', deploymentData);
    }

    deleteDeployment(deploymentId) {
        return OcuService.doApiCall('delete', window.env.API +'/deployments/'+deploymentId, 'deleteDeployment');
    }




    /*Device Presets*/
    getPresets() {
        return OcuService.doApiCall('get', window.env.API + '/devicepresets');
    }

    createPreset(preset) {
        return OcuService.doApiCall('put', window.env.API + '/devicepresets', 'createPreset', preset);
    }

    updatePreset(presetId, presetData) {
        return OcuService.doApiCall('post', window.env.API + '/devicepresets/' + presetId, 'updatePreset', presetData);


    }

    deletePreset(presetId) {
        return OcuService.doApiCall('delete', window.env.API + '/devicepresets/' + presetId, 'deletePreset');
    }
}


export default new DeviceService();
