import OcuService from "../OcuService";
import axios from "axios/index";

class UserService {
    loginUser(data) {
        return OcuService.doApiCall("post", "oauth/token", "loginUser", data);
    }

    getUser(userId = null) {
        return OcuService.doApiCall(
            "get",
            `${window.env.API}/users/${userId || "current"}`,
            "getUser"
        );
    }

    getAllUsers() {
        return OcuService.doApiCall(
            "get",
            `${window.env.API}/users/all`,
            "get all users"
        );
    }

    createUser(data) {
        return OcuService.doApiCall(
            "post",
            `${window.env.API}/users`,
            "createUser",
            data
        );
    }

    updateUser(userId, data) {
        return OcuService.doApiCall(
            "put",
            `${window.env.API}/users/${userId}`,
            "updateUser",
            data
        );
    }

    deleteUser(userId) {
        return OcuService.doApiCall(
            "delete",
            `${window.env.API}/users/${userId}`,
            "deleteUser"
        );
    }

    resetUserPassword(email) {
        return OcuService.doApiCall(
            "post",
            `${window.env.API}/users/passwordreset`,
            "resetUserPassword",
            {email}
        );
    }

    getUserAnalytics(params) {
        return OcuService.doExcelCall(
            "post",
            `${window.env.API}/users/statistics`,
            "getUserAnalytics",
            params
        );
    }

    setLastLoggedInAtProperty() {
        return OcuService.doApiCall("post", `${window.env.API}/users/login`);
    }

    getRoles() {
        return OcuService.doApiCall("get", window.env.API + "/roles");
    }

    getLastExport() {
        return OcuService.doApiCall("get", `${window.env.API}/users/lastexport`);
    }

    setRoleToUser(roleId, userId) {
        return OcuService.doApiCall(
            "post",
            `${window.env.API}/roles/${roleId}/users/${userId}`
        );
    }

    setToken(authToken) {
        axios.defaults.headers.common["Authorization"] = `Bearer ${authToken}`;
        return this;
    }

    setLanguage(lang) {
        axios.defaults.headers.common["Content-Language"] = lang;
        return this;
    }

    updateUserPassword({userId, data}) {
        return OcuService.doApiCall(
            "put",
            `${window.env.API}/users/${userId}/password`,
            "updateUserPassword",
            data
        );
    }
}

export default new UserService();
