import CustomerService from "../../services/OcuService/cebeo/customersService";
import {reject, resolve} from "promise-polyfill";

const state = {
    customers: []
};

const mutations = {};

const getters = {};

const actions = {
    //visits

    getCustomerVisits: ({commit}) => {
        return new Promise((resolve, reject) => {
            CustomerService.getCustomerVisits()
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    getCustomerVisitsAccepted: ({commit}) => {
        return new Promise((resolve, reject) => {
            CustomerService.getCustomerVisitsAccepted()
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    getCustomerVisitArchive: ({commit}) => {
        return new Promise((resolve, reject) => {
            CustomerService.getCustomerVisitArchive()
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    getArchivedVisit: ({}, visit) => {
        return new Promise((resolve, reject) => {
            CustomerService.getArchivedVisit(visit)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    getHandledVisits: ({}) => {
        return new Promise((resolve, reject) => {
            CustomerService.getHandledCustomerVisits()
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    createCustomerVisit: ({commit}, customerVisitData) => {
        return new Promise((resolve, reject) => {
            CustomerService.createCustomerVisit(customerVisitData)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    getCustomerVisit: ({commit}, customerVisitId) => {
        return new Promise((resolve, reject) => {
            CustomerService.getCustomerVisit(customerVisitId)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    updateCustomerVisit: ({commit}, {customerVisitId, customerVisitData}) => {
        return new Promise((resolve, reject) => {
            CustomerService.updateCustomerVisit(
                customerVisitId,
                customerVisitData
            )
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    updateTimeslot: ({commit}, data) => {
        return new Promise((resolve, reject) => {
            CustomerService.updateTimeslot(data)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    deleteCustomerVisit: ({commit}, customerVisitId) => {
        return new Promise((resolve, reject) => {
            CustomerService.deleteCustomerVisit(customerVisitId)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    acceptCustomerVisit: ({commit}, customerVisitId) => {
        return new Promise((resolve, reject) => {
            CustomerService.acceptCustomerVisit(customerVisitId)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    refuseCustomerVisit: ({commit}, customerVisitId) => {
        return new Promise((resolve, reject) => {
            CustomerService.refuseCustomerVisit(customerVisitId)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },


    cancelCustomerVisit: ({commit}, customerVisitId) => {
        return new Promise((resolve, reject) => {
            CustomerService.cancelCustomerVisit(customerVisitId)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    uploadFloorplanCustomerVisit: ({commit}, {customerVisitId, file}) => {
        const data = new FormData();
        data.append("file", file);
        return new Promise((resolve, reject) => {
            CustomerService.uploadFloorplanCustomerVisit(customerVisitId, data)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    copyFloorplanCustomerVisit: ({commit}, {customerVisitId, originalId}) => {
        return new Promise((resolve, reject) => {
            CustomerService.copyFloorplanCustomerVisit(
                customerVisitId,
                originalId
            )
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    deleteFloorPlanCustomerVisit: ({}, {customerVisitId, floorPlanAssetId}) => {
        return new Promise((resolve, reject) => {
            CustomerService.deleteFloorPlanCustomerVisit(
                customerVisitId,
                floorPlanAssetId
            )
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    getCustomerVisitOffers: ({commit}, customerVisitId) => {
        return new Promise((resolve, reject) => {
            CustomerService.getCustomerVisitOffers(customerVisitId)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    updateOffer: ({commit}, {offerId, offerData}) => {
        return new Promise((resolve, reject) => {
            CustomerService.updateOffer(offerId, offerData)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    uploadOfferFile: ({commit}, {offerId, file}) => {
        const data = new FormData();
        data.append("file", file);
        return new Promise((resolve, reject) => {
            CustomerService.uploadOfferFile(offerId, data)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    exportOfferExcel: ({commit}, offerId) => {
        return new Promise((resolve, reject) => {
            CustomerService.exportOfferExcel(offerId)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    exportBom: ({commit}, {offerId, mode}) => {
        return new Promise((resolve, reject) => {
            CustomerService.exportBom(offerId, mode)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    exportA3: ({commit}, offerId) => {
        return new Promise((resolve, reject) => {
            CustomerService.exportA3(offerId)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    handleCustomerVisit: ({}, visitId) => {
        return new Promise((resolve, reject) => {
            CustomerService.setCustomerVisitHandled(visitId)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    unHandleCustomerVisit: ({}, visitId) => {
        return new Promise((resolve, reject) => {
            CustomerService.setCustomerVisitUnHandled(visitId)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    restoreArchived: ({}, visitId) => {
        return new Promise((resolve, reject) => {
            CustomerService.restoreArchived(visitId)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    forceDeleteArchivedVisit: ({}, visitId) => {
        return new Promise((resolve, reject) => {
            CustomerService.forceDeleteVisit(visitId)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    replanVisit: ({}, {visitId, data}) => {
        return new Promise((resolve, reject) => {
            CustomerService.replanVisit({visitId, data})
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    getCustomerFavorites: ({}, visitId) => {
        return new Promise((resolve, reject) => {
            CustomerService.getCustomerFavorites(visitId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        })
    },

    getOfferPdf({}, offerId) {
        return new Promise((resolve, reject) => {
            CustomerService.getOfferPdf(offerId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        })
    },

    exportOfferPdf({}, data) {
        return new Promise((resolve, reject) => {
            CustomerService.exportOfferPdf(data)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        })
    },

    getStatus({}, id) {
        return new Promise((resolve, reject) => {
            CustomerService.getStatus(id)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        })
    },

    getExport({}, id) {
        return new Promise((resolve, reject) => {
            CustomerService.getExport(id)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        })
    },

    getVisitsAsEvents({}, {storeId}) {
        return new Promise((resolve, reject) => {
            CustomerService.getVisitsAsEvents(storeId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        })
    },

    getStoreUsers({}, data) {
        return new Promise((resolve, reject) => {
            CustomerService.getStoreUsers(data)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        })
    },

    duplicateVisit({}, data) {
        return new Promise((resolve, reject) => {
            CustomerService.duplicateVisit(data)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        })
    },

    sendUpdate({}, data) {
        return new Promise((resolve, reject) => {
            CustomerService.sendUpdate(data)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        })
    },

    uploadReference({}, data) {
        return new Promise((resolve, reject) => {
            CustomerService.uploadReference(data)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        })
    },

    clearAttribute({}, data) {
        return new Promise((resolve, reject) => {
            CustomerService.clearAttribute(data)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        })
    },

    addReferencePage({}, data) {
        return new Promise((resolve, reject) => {
            CustomerService.addReferencePage(data)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        })
    },

    swapReferencePages({}, data){
        return new Promise((resolve, reject) => {
            CustomerService.swapReferencePages(data)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    updateReferencePageType({}, data){
        return new Promise((resolve, reject) => {
            CustomerService.updateReferencePageType(data)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getPageTypes() {
        return new Promise((resolve, reject) => {
            CustomerService.getPageTypes()
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        })

    },

    deleteReferencePage({}, data){
        return new Promise((resolve, reject) => {
            CustomerService.deleteReferencePage(data)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    saveReferencePageText({}, data) {
        return new Promise((resolve, reject) => {
            CustomerService.saveReferencePageText(data)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        })
    }
};

export default {
    state,
    actions,
    mutations,
    getters
};
