import ProductService from "../../services/OcuService/cebeo/productsService";

const state = {
    products: [],
};

const mutations = {};

const getters = {};

const actions = {
    getProducts: ({commit}, page) => {
        return new Promise((resolve, reject) => {
            ProductService.getProducts(page)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getProduct: ({commit}, productId) => {
        return new Promise((resolve, reject) => {
            ProductService.getProduct(productId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    createProduct: ({commit}, productData) => {
        return new Promise((resolve, reject) => {
            ProductService.createProduct(productData)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    updateProduct: ({commit}, {productId, data}) => {
        return new Promise((resolve, reject) => {
            ProductService.updateProduct(productId, data)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    deleteProduct: ({commit}, {productId}) => {
        return new Promise((resolve, reject) => {
            ProductService.deleteProduct(productId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getFacets: ({commit}, data) => {
        return new Promise((resolve, reject) => {
            ProductService.getFacets(data)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },


    getSuggestions: ({commit}, data) => {
        return new Promise((resolve, reject) => {
            ProductService.getSuggestions(data)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getFilteredProducts: (context, queryData) => {
        const data = {
            ...queryData.query,
            sort: queryData.sort
        };
        const page = queryData.page;
        const amount = queryData.amount || 25;
        return new Promise((resolve, reject) => {

            ProductService.getFilteredProducts(data, page, amount)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    uploadProductFile: (context, {productId, file}) => {
        const data = new FormData();
        data.append("file", file);
        return new Promise((resolve, reject) => {
            ProductService.uploadProductFile(productId, data)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    deleteProductFile: (context, {productId, productAssetId}) => {
        return new Promise((resolve, reject) => {
            ProductService.deleteProductFile(productId, productAssetId)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    getRFIDCodes: ({commit}) => {
        return new Promise((resolve, reject) => {
            ProductService.getRFIDCodes()
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getRFID: ({commit}, {tagId}) => {
        return new Promise((resolve, reject) => {
            ProductService.getRFID(tagId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    uploadAmbienceProduct: ({commit}, {productId, file, position, tags}) => {
        const data = new FormData();
        data.append("file", file);
        data.append("position", position);
        data.append("tags", JSON.stringify(tags));
        return new Promise((resolve, reject) => {
            ProductService.uploadAmbience(productId, data)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    deleteAmbienceProduct: ({commit}, {productId, ambienceId}) => {
        return new Promise((resolve, reject) => {
            ProductService.deleteAmbienceProduct(productId, ambienceId)
                .then(response => resolve(response))
                .catch(error => reject(error));
        })
    },

    updateAmbiencesProduct: ({commit}, {productId, ambiencesData}) => {
        return new Promise((resolve, reject) => {
            ProductService.updateAmbiencesProduct(productId, ambiencesData)
                .then(response => resolve(response))
                .catch(error => reject(error));
        })
    },

    addImagesToProduct: ({commit}, {productId, images}) => {
        return new Promise((resolve, reject) => {
            ProductService.addImagesToProduct(productId, images)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    }
};


export default {
    state,
    actions,
    mutations,
    getters
}
