import AssetService from '../../../services/OcuService/modules/assetService';

const state = {
    assets: [],
    projectDependencies: [],
};

const mutations = {
    SET_ASSETS(state, assets) {
        state.assets = assets;
    },
    SET_PROJECT_DEPENCENCY(state, projectDependency) {
        state.projectDependencies = projectDependency;
    }
};

const getters = {
    getAssets: (state) => () => {
        return state.assets;
    },
    getProjectDependency: (state) => () => {
        return state.projectDependencies
    }
};

const actions = {
    getAssets: ({
        commit,
        getters
    }) => {
        return new Promise((resolve, reject) => {
            if (getters.getAssets().length > 0) {
                resolve(getters.getAssets().splice(0));
            } else {
                AssetService.getAssets()
                    .then((response) => {
                        commit('SET_ASSETS', response);
                        resolve(response);
                    })
                    .catch((error) => reject(error));
            }
        });
    },

    getAssetById: ({
        getters
    }, assetId) => {
        return new Promise((resolve, reject) => {
            AssetService.getAssetById(assetId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getContentOfAsset: (assetId) => {
        return new Promise((resolve, reject) => {
            AssetService.getAssetContent(assetId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getContentOfAssetBySearch: ({
        assetId,
        search
    }) => {
        return new Promise((resolve, reject) => {
            AssetService.getAssetContentBySearch(assetId, search)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getSpecificAsset: ({
        commit,
        getters
    }) => {
        return new Promise((resolve, reject) => {
            if (getters.getProjectDependency().length !== 0) {
                resolve(getters.getProjectDependency())
            } else {
                AssetService.getSpecificAsset()
                    .then((response) => {
                        commit('SET_PROJECT_DEPENCENCY', response);
                        resolve(response);
                    })
                    .catch((error) => reject(error));
            }
        });
    },

    clearAndFetchSpecificAsset: ({
        commit
    }) => {
        return new Promise((resolve, reject) => {
            commit('SET_PROJECT_DEPENCENCY', []);
            AssetService.getSpecificAsset()
                .then((response) => {
                    commit('SET_PROJECT_DEPENCENCY', response);
                    resolve(response);
                })
                .catch((error) => reject(error));
        })
    },

    reIndexAssets: ({
        projectId
    }) => {
        return new Promise((resolve, reject) => {
            AssetService.reIndexAssets(projectId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getListOfAssets: ({
        projectId
    }) => {
        return new Promise((resolve, reject) => {
            AssetService.getListOfAssets(projectId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    /*Generic module assets*/
    resolveAsset: ({
        commit
    }, {
        assetId,
        moduleId
    }) => {
        return new Promise((resolve, reject) => {
            AssetService.resolveAsset(assetId, moduleId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    addAssetsToGenericModule: ({
        commit
    }, {
        assetsArray,
        moduleId
    }) => {
        return new Promise((resolve, reject) => {
            AssetService.addAssetToGenericModule({
                    assets: assetsArray
                }, moduleId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    deleteAssetsFromGenericModule: ({}, {
        assetsArray,
        moduleId
    }) => {
        return new Promise((resolve, reject) => {
            AssetService.deleteAssetFromGenericModule({
                    "_method": "delete",
                    "assets": assetsArray
                }, moduleId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },


    deleteAssets: (context, path) => {
        return new Promise((resolve, reject) => {
            //@TODO: deleten van asset uit store
            AssetService.deleteAsset(path)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    deleteAllAssetsForModule: ({}, moduleId) => {
        return new Promise((resolve, reject) => {
            AssetService.deleteAllAssetsForModule(moduleId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        })
    },

    getCrossbarSettings: () => {
        return new Promise((resolve, reject) => {
            AssetService.getCrossbarSettings()
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    }
};

export default {
    state,
    actions,
    mutations,
    getters
}
