import DeviceService from '../../../services/OcuService/modules/deviceService';

const state = {
    deployments: [],
};

const mutations = {
    SET_DEPLOYMENT(state, deployment) {
        let deployObject = state.deployments.find(x => x.id === deployment.id);

        if (deployObject) {
            let index = state.deployments.findIndex(x => x.id === deployment.id);
            state.deployments[index] = deployment;
        } else {
            state.deployments.push(deployment);
        }
    }

};

const getters = {};

const actions = {
    getDeployment: ({
        commit
    }, deploymentId) => {
        return new Promise((resolve, reject) => {
            DeviceService.getDeployment(deploymentId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    createDeployment: ({
        commit
    }, {
        deploymentData
    }) => {
        let dataObj = {
            deviceId: deploymentData.deviceId,
            applicationId: deploymentData.applicationId,
            devicePresetId: deploymentData.devicePresetId,
            exhibitId: deploymentData.exhibitId,
            actionId: deploymentData.actionId
        };

        return new Promise((resolve, reject) => {
            DeviceService.createDeployment(dataObj)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    updateDeployment: ({
        commit
    }, {
        deploymentData,
        deploymentId
    }) => {
        let dataObj = {
            deviceId: deploymentData.deviceId,
            applicationId: deploymentData.applicationId,
            devicePresetId: deploymentData.devicePresetId,
            exhibitId: deploymentData.exhibitId,
            actionId: deploymentData.actionId
        };
        return new Promise((resolve, reject) => {
            DeviceService.updateDeployment(dataObj, deploymentId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    deleteDeployment: ({
        commit
    }, {
        deploymentId
    }) => {
        return new Promise((resolve, reject) => {
            DeviceService.deleteDeployment(deploymentId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    }
};


export default {
    state,
    mutations,
    getters,
    actions
}
