import DeviceService from "../../../services/OcuService/modules/deviceService";

const state = {
    deviceGroups: [],
};
const mutations = {
    SET_DEVICE_GROUPS(state, deviceGroups) {
        state.deviceGroups = deviceGroups;
    },

    SET_DEVICE_GROUP(state, deviceGroup) {
        /*check if deviceGroup exists in store : Y=> update  N=>create */
        let deviceGroupInStore = state.deviceGroups.find(x => x.id === deviceGroup.id);

        if (deviceGroupInStore !== undefined) {
            /*Device Group exists => update*/
            let index = state.deviceGroups.findIndex(x => x.id === deviceGroup.id);
            state.deviceGroups[index] = deviceGroup;
        } else {
            state.deviceGroups.push(deviceGroup)
        }
    },

    DELETE_DEVICE_GROUP(state, deviceGroupId) {
        /*Filter deleted deviceGroup from current stored deviceGroups*/
        state.deviceGroups = state.deviceGroups.filter(x => x.id !== deviceGroupId);
    }
};
const getters = {
    getDeviceGroups: (state) => () => {
        return state.deviceGroups;
    }
};
const actions = {
    getDeviceGroups: ({commit, getters}) => {
        return new Promise((resolve, reject) => {

            DeviceService.getDeviceGroups()
                .then((response) => {
                    commit('SET_DEVICE_GROUPS', response);
                    resolve(response);
                })
                .catch((error) => reject(error));

        });
    },

    createDeviceGroup: ({commit, getters}, deviceGroupProps) => {
        let deviceGroup = {
            name: deviceGroupProps.name,
            deviceTypeId: deviceGroupProps.deviceTypeId,
            exhibitId: deviceGroupProps.exhibitId,
            devices: deviceGroupProps.devices
        };

        return new Promise((resolve, reject) => {
            DeviceService.createDeviceGroup(deviceGroup)
                .then((response) => {
                    // commit('SET_DEVICE_GROUP', response);
                    resolve(response);
                })
                .catch((error) => reject(error));
        });
    },

    getDeviceGroup: (context, deviceGroupID) => {
        return new Promise((resolve, reject) => {
            DeviceService.getDeviceGroup(deviceGroupID)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    updateDeviceGroup: ({commit, getters}, deviceGroupProps) => {
        let deviceGroup = {
            name: deviceGroupProps.name,
            deviceTypeId: deviceGroupProps.deviceTypeId,
            exhibitId: deviceGroupProps.exhibitId,
            devices: deviceGroupProps.devices
        };

        return new Promise((resolve, reject) => {
            DeviceService.updateDeviceGroup(deviceGroupProps.deviceGroupId, deviceGroup)
                .then((response) => {
                    commit('SET_DEVICE_GROUP', response);
                    resolve(response);
                })
                .catch((error) => reject(error));
        });


    },

    deleteDeviceGroup: ({commit, getters}, deviceGroupID) => {
        return new Promise((resolve, reject) => {
            DeviceService.deleteDeviceGroup(deviceGroupID)
                .then((response) => {
                    commit('DELETE_DEVICE_GROUP', deviceGroupID);
                    resolve(response);
                })
                .catch((error) => reject(error));
        });
    },

    getDevicesInDeviceGroup: (context, deviceGroupID) => {
        return new Promise((resolve, reject) => {
            DeviceService.getDevicesInDeviceGroup(deviceGroupID)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    syncDevicesInDeviceGroup: () => {
        return new Promise((resolve, reject) => {
            DeviceService.syncDevicesInDevicegroup()
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    }
};


export default {
    state, mutations, getters, actions
}
