import DeviceService from '../../../services/OcuService/modules/deviceService';

const state = {
    devices: [],
    deviceGroups: [],
    deviceTypes: [],
};

const mutations = {
    /* Devices*/
    SET_DEVICES(state, devices) {
        state.devices = devices;
    },

    SET_DEVICE(state, device) {
        /*check if device exists in store ->Y : update >N : create*/
        let deviceInStore = state.devices.find(x => x.id === device.id);

        if (deviceInStore !== undefined) {
            /*Update Stored Device*/
            let index = state.devices.findIndex(x => x.id === device.id);
            state.devices[index] = device;
        } else {
            /*Add new device to store*/
            state.devices.push(device);
        }
    },

    DELETE_DEVICE(state, deviceId) {
        state.devices = state.devices.filter(x => x.id !== deviceId);
    },


};

const getters = {
    getDevices: (state) => () => {
        return state.devices;
    }
};

const actions = {
    getDevices: ({commit, getters}) => {
        return new Promise((resolve, reject) => {
            if (getters.getDevices().length > 0) {
                //clone array to prevent data mutated from outside
                resolve(getters.getDevices().slice(0));
            } else {
                DeviceService.getDevices()
                    .then((response) => resolve(response))
                    .catch((error) => reject(error));
            }
        });
    },

    createDevice: ({commit}, deviceProps) => {
        let device = {
            name: deviceProps.name,
            address: deviceProps.address,
            deviceTypeId: deviceProps.deviceTypeId,
            exhibitId: deviceProps.exhibitId,
            exhibitResourceLineId: deviceProps.exhibitResourceLineId,
            scenario_client_id: deviceProps.scenarioClientId,
        };

        return new Promise((resolve, reject) => {
            DeviceService.createDevice(device)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getDevice: (context, deviceID) => {
        return new Promise((resolve, reject) => {
            DeviceService.getDevice(deviceID)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    updateDevice: ({commit, getters}, deviceProps) => {
        let device = {
            name: deviceProps.name,
            address: deviceProps.address,
            deviceTypeId: deviceProps.deviceTypeId,
            exhibitId: deviceProps.exhibitId,
            exhibitResourceLineId: deviceProps.exhibitResourceLineId,
        };

        return new Promise((resolve, reject) => {
            DeviceService.updateDevice(deviceProps.deviceId, device)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    deleteDevice: ({commit, getters}, deviceID) => {
        return new Promise((resolve, reject) => {
            DeviceService.deleteDevice(deviceID)
                .then(() => resolve(getters.getDevices()))
                .catch((error) => reject(error));
        });
    },

    previewDevice: ({commit, getters}, deviceId) => {
        return new Promise((resolve, reject) => {
            DeviceService.previewDevice(deviceId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getDeviceGroupsForDevice: ({commit, getters}, deviceID) => {
        return new Promise((resolve, reject) => {
            DeviceService.getDeviceGroupsForDevice(deviceID)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

};


export default {
    state, actions, mutations, getters
}
