import deviceService from '../../../services/OcuService/modules/deviceService';

const state = {
    presets: []
};

const mutations = {
    SET_PRESETS(state, presets) {
        state.presets = presets;
    },

    ADD_PRESET(state, preset) {
        /*Check if new preset or update preset*/
        let presetInDB = state.presets.find(x => x.id === preset.id);

        if (presetInDB !== undefined) {
            /*update preset*/
            let index = state.presets.findIndex(x => x.id === preset.id);
            state.presets[index] = preset;
        } else {
            state.presets.push(preset);
        }
    },

    DELETE_PRESET(state, presetId) {
        state.presets = state.presets.filter(x => x.id !== presetId);
    },
};

const getters = {
    getPresets: (state) => () => {
        return state.presets;
    }
};

const actions = {
    getPresets: ({commit, getters}) => {
        return new Promise((resolve, reject) => {
            deviceService.getPresets()
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    createPreset: ({commit}, newPreset) => {
        let preset = {
            name: newPreset.name,
            loop: newPreset.loop,
            deviceTypeId: newPreset.deviceTypeId,
            settings: newPreset.settings,
        };

        return new Promise((resolve, reject) => {
            deviceService.createPreset(preset)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    updatePreset: ({commit}, updatedPreset) => {
        let preset = {
            name: updatedPreset.name,
            loop: updatedPreset.loop,
            deviceTypeId: updatedPreset.deviceTypeId,
            settings: updatedPreset.settings,
        };

        return new Promise((resolve, reject) => {
            deviceService.updatePreset(updatedPreset.presetId, preset)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    deletePreset: ({commit}, presetId) => {
        return new Promise((resolve, reject) => {
            deviceService.deletePreset(presetId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    }
};

export default {
    state, mutations, getters, actions
}
