import DocumentService from '../../../services/OcuService/modules/documentService';
import Vue from 'vue';

const state = {
    documents: [],
    requestedTypes: []
};

const mutations = {
    SET_DOCUMENTS_OF_TYPE(state, obj) {
        state.documents.forEach((documents, index) => {
            if (documents.id === parseInt(obj.typeid)) {
                Vue.set(state.documents[index], 'data', '');
                Vue.set(state.documents[index], 'data', obj.responseData);
            }
        });
    },

    SET_DOCUMENT(state, obj) {
        /*find document in state.documents with typeid param*/
        let documentInStore = state.documents.find(x => x.id === obj.typeid);

        if (documentInStore !== undefined) {
            if (documentInStore.data) {
                documentInStore.data.forEach((dataItem, index) => {
                    if (dataItem.id === obj.responseData.id) {
                        state.documents[state.documents.indexOf(documentInStore)].data[index] = Object.assign({}, obj.responseData);
                    }
                });
            } else {
                documentInStore.data = [obj.responseData];
            }
        }
    },

    UNSET_DOCUMENT(state, documentid) {
        state.documents.forEach((documents) => {
            if (documents.data) {
                documents.data = documents.data.filter(x => x !== (documents.data.find(x => x.id === documentid)));
            }
        });
    }
};

const getters = {
    getDocumentsByTypeId: (state) => (typeid) => {
        let documentData = state.documents.find(x => x.id === parseInt(typeid));
        return (documentData) ? documentData.data : null;
    },

    getDocument: (state) => (documentid) => {
        let objDocument = null;
        state.documents.forEach((documents) => {
            if (documents.data) {
                let documentInStore = documents.data.find(x => x.id === documentid);
                objDocument = (documentInStore) ? documentInStore : null;
            }
        });
        return objDocument;
    },

    getDocumentType: (state) => (typeid) => {
        let documentData = state.documents.find(x => x.id === parseInt(typeid));
        return (documentData) ? documentData : null;
    },

    getDocumentTypeSetted: (state) => (type) => {
        let documentType = state.documents.find(x => x.id === parseInt(type));
        return (documentType === undefined || documentType === null);
    }
};

const actions = {
    getDocumentTypes: ({}) => {
        return new Promise((resolve, reject) => {
            DocumentService.getDocumentTypes()
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getDocumentType: ({commit}, typeid) => {
        return new Promise((resolve, reject) => {
            DocumentService.getDocumentType(typeid)
                .then((responseType) => resolve(responseType))
                .catch((error) => reject(error));
        });
    },

    setDocumentType: ({commit}, typeid) => {
        return new Promise((resolve, reject) => {
            DocumentService.getDocumentType(typeid)
                .then((responseType) => {
                    if (!state.documents.find(x => x.name === responseType.name)) {
                        responseType.data = null;
                        state.documents.push(responseType);
                    }
                    resolve(true);
                })
                .catch((error) => reject(error));
        });
    },


    setDocumentsOfType: ({getters, dispatch}, typeid) => {
        return new Promise((resolve, reject) => {
            //if not fetched yet
            (!state.requestedTypes.indexOf(typeid))
                ? dispatch('_setDocumentsOTypeInStore', typeid)
                    .then((response) => resolve(response))
                    .catch((errors) => reject(errors))
                : dispatch('_updateDocumentsOTypeInStore', typeid)
                    .then((response) => resolve(response))
                    .catch((errors) => reject(errors));

            state.requestedTypes.push(typeid);
        });
    },

    getDocumentsForType: ({commit}, typeid) => {
        return new Promise((resolve, reject) => {
            DocumentService.getDocumentsForType(typeid)
                .then((responseData) => {
                    commit('SET_DOCUMENTS_OF_TYPE', {typeid: typeid, responseData: responseData});
                    resolve(responseData);
                })
                .catch((error) => reject(error));
        });
    },


    getDocument: ({commit, getters, dispatch}, documentid) => {
        return new Promise((resolve, reject) => {
            const documentFromStore = getters.getDocument(documentid);
            if (documentFromStore !== null) resolve(documentFromStore);

            DocumentService.getDocument(documentid)
                .then((response) => {
                    if (typeof response.data === "string")
                        response.data = JSON.parse(response.data);

                    commit('SET_DOCUMENT', {typeid: response.document_type_id, responseData: response});
                    resolve(response);
                })
                .catch((error) => reject(error));
        });
    },

    createDocument: ({commit, dispatch}, objData) => {
        return new Promise((resolve, reject) => {
            const dataObj = {typeid: objData.typeid, data: objData.data, action: "create"};
            //get default json from document type
            let documentTypeDefaultData = state.documents.find(x => x.id === parseInt(objData.typeid));

            if (!documentTypeDefaultData) {
                dispatch('_getDocumentTypeToCompairDefaultData', dataObj)
                    .then((response) => resolve(response))
                    .catch((error) => reject(error));

            } else {
                const obj = {
                    data: objData.data,
                    documentTypeDefaultData: documentTypeDefaultData.default_data,
                    typeid: objData.typeid
                };
                dispatch('_getStoreDefaultDataToCompairAndSaveToDocumentsInStore', obj)
                    .then((response) => resolve(response))
                    .catch((error) => reject(error));
            }
        });
    },


    updateDocument: ({commit, dispatch}, objData) => {
        return new Promise((resolve, reject) => {
            const obj = {typeid: objData.typeid, documentid: objData.documentid, data: objData.data, action: "update"};
            //get default json from document type
            let documentTypeDefaultData = state.documents.find(x => x.id === parseInt(objData.typeid));
            if (!documentTypeDefaultData) {
                dispatch('_getDocumentTypeToCompairDefaultData', obj)
                    .then((response) => resolve(response))
                    .catch((error) => reject(error));
            } else {
                const objCopy = {data: objData.data, documentTypeDefaultData: documentTypeDefaultData.default_data};
                dispatch('_compairDefaultDataWithPostData', objCopy)
                    .then((response) => {
                        dispatch('_updateDocumentInDatabase', {typeid: obj.typeid, documentid: obj.documentid, resp: response})
                            .then((response) => resolve(response))
                            .catch((error) => reject(error))
                    })
                    .catch((error) => reject(error));
            }
        });
    },

    deleteDocument: ({commit}, documentid) => {
        return new Promise((resolve, reject) => {
            DocumentService.deleteDocument(documentid)
                .then((response) => {
                    commit('UNSET_DOCUMENT', documentid);
                    resolve(response);
                })
                .catch((error) => reject(error));
        });
    },

    setArchiveStateDocument: ({commit, dispatch}, obj) => {
        return new Promise((resolve, reject) => {
            dispatch('getDocument', obj.documentid)
                .then((response) => {
                    const documentData = Object.assign({}, response.data);
                    documentData.isActive = obj.isActive;

                    const updateObj = {typeid: response.document_type_id, documentid: obj.documentid, data: documentData};

                    dispatch('updateDocument', updateObj)
                        .then((response) => resolve(response))
                        .catch((errors) => reject(errors));
                })
                .catch((error) => reject(error));
        });
    },

    getFormData: ({commit, getters, dispatch}, obj) => {
        return new Promise((resolve, reject) => {
            //check if documents are loaded into the store
            const documentsAlreadySetted = getters.getDocumentTypeSetted(parseInt(obj.typeid));
            const formDataObj = {typeid: parseInt(obj.typeid), documentid: obj.documentid, documentsAlreadySetted: documentsAlreadySetted};

            //if form is edit form, get data from store
            (obj.documentid)
                ? dispatch('_getFormDataFromDocumentId', formDataObj)
                    .then((resp) => resolve(resp))
                    .catch((error) => reject(error))
                : dispatch('_getFormDataFromDocumentType', formDataObj)
                    .then((resp) => resolve(resp))
                    .catch((error) => reject(error))
        });
    },

    getDefaultDocumentData: ({commit, getters, dispatch}, documentTypeId) => {
        return new Promise((resolve, reject) => {
            (!getters.getDocumentTypeSetted(documentTypeId))
                ? resolve(getters.getDocumentType(documentTypeId).default_data)
                : dispatch('setDocumentsOfType', documentTypeId)
                    .then(() => resolve(Object.assign({}, getters.getDocumentType(documentTypeId).default_data)))
                    .catch((error) => reject(error));
        })
    },


    //PRIVATE FUNCTIONS
    _compairDefaultDataWithPostData: ({commit, dispatch}, objData) => {
        return new Promise((resolve, reject) => {
            // get object keys from default json and data
            let keysObjData = Object.keys(objData.data);
            let keysDefaultData = Object.keys(objData.documentTypeDefaultData);

            //if different, add empty parameter
            if (keysObjData.length !== keysDefaultData.length) {
                let mergedDocument = Object.assign({}, objData.documentTypeDefaultData, objData.data);
                objData.data = null;
                objData.data = mergedDocument;
                keysObjData = Object.keys(objData.data);
            }

            keysObjData.sort();
            keysDefaultData.sort();

            //compair if keys are the same
            let errors = false;

            keysDefaultData.forEach((keysDefaultDataItem, index) => {
                if (keysDefaultDataItem !== keysObjData[index]) errors = true;
            });

            (errors)
                //if keys aren't the same, show error with default json
                ? reject({
                    msg: "The document you are trying to save does not match the default json.",
                    defaultJson: objData.documentTypeDefaultData,
                    data: objData.data
                })
                //if keys are the same, save data
                : resolve(objData.data);

        });
    },

    _getDocumentTypeToCompairDefaultData: ({dispatch, commit}, obj) => {
        return new Promise((resolve, reject) => {
            //get document type to get default data
            dispatch('getDocumentType', obj.typeid)
                .then((response) => {
                    dispatch('_compairDefaultDataWithPostData', {data: obj.data, documentTypeDefaultData: response.default_data})
                        .then((resp) => {
                            if (obj.action === "create") {
                                dispatch('_createDocumentInDatabase', {typeid: obj.typeid, resp: resp})
                                    .then((response) => resolve(response))
                                    .catch((error) => reject(error))
                            } else if (obj.action === "update") {
                                dispatch('_updateDocumentInDatabase', {typeid: obj.typeid, documentid: obj.documentid, resp: resp})
                                    .then((response) => resolve(response))
                                    .catch((error) => reject(error))
                            }
                        });
                })
                .catch((error) => reject(error));
        });
    },

    _getStoreDefaultDataToCompairAndSaveToDocumentsInStore: ({dispatch}, obj) => {
        return new Promise((resolve, reject) => {
            dispatch('_compairDefaultDataWithPostData', obj)
                .then((response) => {
                    dispatch('_createDocumentInDatabase', {typeid: obj.typeid, resp: response})
                        .then((response) => resolve(response))
                        .catch((error) => reject(error));
                });
        });
    },

    _setDocumentsOTypeInStore: ({getters, dispatch}, typeid) => {
        return new Promise((resolve, reject) => {
            const documentsAlreadySetted = getters.getDocumentTypeSetted(typeid);
            if (!documentsAlreadySetted) {
                //if type data excists, just get documents
                dispatch('getDocumentsForType', typeid)
                    .then((response) => resolve(response))
                    .catch((errors) => reject(errors));
            } else {
                //if type data doesn't excist, get type and documents
                DocumentService.getDocumentType(typeid)
                    .then((responseType) => {
                        if (!state.documents.find(x => x.name === responseType.name)) {
                            responseType.data = null;
                            state.documents.push(responseType);
                        }

                        dispatch('getDocumentsForType', typeid)
                            .then((response) => resolve(response))
                            .catch((errors) => reject(errors));
                    })
                    .catch((error) => reject(error));
            }
        });
    },

    _updateDocumentsOTypeInStore: ({getters, dispatch}, typeid) => {
        return new Promise((resolve, reject) => {
            const documentsAlreadySetted = getters.getDocumentTypeSetted(typeid);
            if (!documentsAlreadySetted) {
                resolve(getters.getDocumentsByTypeId(typeid));
            } else {
                //if type data doesn't excist, get everything
                DocumentService.getDocumentType(typeid)
                    .then((responseType) => {
                        if (!state.documents.find(x => x.name === responseType.name)) {
                            responseType.data = null;
                            state.documents.push(responseType);
                        }

                        dispatch('getDocumentsForType', typeid)
                            .then((response) => resolve(response))
                            .catch((errors) => reject(errors));
                    })
                    .catch((error) => reject(error));
            }
        });
    },

    _createDocumentInDatabase: ({commit}, obj) => {
        return new Promise((resolve, reject) => {
            DocumentService.createDocument(obj.typeid, obj.resp)
                .then((response) => {
                    if (typeof response.data === "string")
                        response.data = JSON.parse(response.data);

                    commit('SET_DOCUMENT', {typeid: obj.typeid, responseData: response});
                    resolve(response);
                })
                .catch((error) => reject(error));
        });
    },

    _updateDocumentInDatabase: ({commit}, obj) => {
        return new Promise((resolve, reject) => {
            DocumentService.updateDocument(obj.documentid, obj.resp)
                .then((response) => {
                    if (typeof response.data === "string")
                        response.data = JSON.parse(response.data);

                    commit('SET_DOCUMENT', {typeid: obj.typeid, responseData: response});
                    resolve(response);
                })
                .catch((error) => reject(error));
        });
    },

    _getFormDataFromDocumentId: ({getters, dispatch}, obj) => {
        return new Promise((resolve, reject) => {
            let documentData = null;
            if (!obj.documentsAlreadySetted) {
                //documents exists, get the document data
                documentData = getters.getDocument(obj.documentid).data;
                //if document data doesn't exists, show 404
                (typeof documentData === "undefined")
                    ? reject()
                    : resolve(Object.assign({}, getters.getDocument(obj.documentid).data));

            } else {
                dispatch('setDocumentsOfType', obj.typeid)
                    .then((resp) => {
                        //documents exists, get the document data
                        documentData = Object.assign({}, resp.find(x => x.id === obj.documentid).data);
                        (typeof documentData === "undefined")
                            ? reject()
                            : resolve(Object.assign({}, documentData));
                    })
                    .catch((error) => reject(error));
            }
        });
    },

    _getFormDataFromDocumentType: ({getters, dispatch}, obj) => {
        return new Promise((resolve, reject) => {
            if (!obj.documentsAlreadySetted) {
                resolve(Object.assign({}, getters.getDocumentType(obj.typeid).default_data));
            } else {
                dispatch('setDocumentsOfType', obj.typeid)
                    .then(() => resolve(Object.assign({}, getters.getDocumentType(obj.typeid).default_data)))
                    .catch((error) => reject(error));
            }
        });
    }
};

export default {
    state, mutations, actions, getters
}
