import ExhibitService from "../../services/OcuService/modules/exhibitService";

const state = {
    exhibits: [],
    devicesInExhibit: [],
};

const mutations = {
    SET_EXHIBITS(state, exhibits) {
        state.exhibits = exhibits;
    },

    ADD_EXHIBIT(state, exhibit) {
        let exhibitInStore = state.exhibits.find(x => x.id === exhibit.id);

        if (exhibitInStore !== undefined) {
            let index = state.exhibits.findIndex(x => x.id === exhibit.id);
            state.exhibits[index] = exhibit;
        } else {
            state.exhibits.push(exhibit);
        }

    },

    DELETE_EXHIBIT(state, exhibitId) {
        state.exhibits = state.exhibits.filter(x => x.id !== exhibitId);
    },

    SET_DEVICES_IN_EXHIBIT(state, exhibitId, devices) {
        state.devicesInExhibit[exhibitId] = (devices === undefined ? [] : devices);
    },

    ADD_RESOURCE_LINES_TO_EXHIBIT() {

    }
};

const getters = {
    getExhibits: (state) => () => {
        return state.exhibits;
    },

    getDevicesInExhibit: (state) => (exhibitID) => {
        if (state.devicesInExhibit[exhibitID] !== undefined) {
            return state.devicesInExhibit[exhibitID];
        }

        return [];
    }
};

const actions = {
    getExhibits: ({commit, getters}) => {
        return new Promise((resolve, reject) => {
            if (getters.getExhibits().length > 0) {
                resolve(Object.assign({}, getters.getExhibits()))
            } else {
                ExhibitService.getExhibits()
                    .then((response) => resolve(response))
                    .catch((error) => reject(error));
            }
        });
    },

    getAllExhibits: ({}) => {
        return new Promise((resolve, reject) => {
            ExhibitService.getAllExhibits()
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    createExhibit: ({commit}, exhibitProps) => {
        let exhibit = {
            name: exhibitProps.name,
            label: exhibitProps.label,
            projectId: exhibitProps.projectId
        };

        return new Promise((resolve, reject) => {
            ExhibitService.createExhibit(exhibit)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },


    getExhibit: ({commit}, exhibitID) => {
        return new Promise((resolve, reject) => {
            ExhibitService.getExhibit(exhibitID)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    updateExhibit: ({commit}, {exhibitData, exhibitId}) => {
        let dataObj = {
            name: exhibitData.name,
            label: exhibitData.label,
            projectId: exhibitData.projectId
        };

        return new Promise((resolve, reject) => {
            ExhibitService.updateExhibit(dataObj, exhibitId)
                .then((response) => resolve(response))
                .catch((error) => reject(error))
        })
    },

    deleteExhibit: ({commit}, exhibitId) => {
        return new Promise((resolve, reject) => {
            ExhibitService.deleteExhibit(exhibitId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getDevicesInExhibit: ({commit, getters}, exhibitID) => {
        return new Promise((resolve, reject) => {
            if (getters.getDevicesInExhibit(exhibitID).length > 0) {
                resolve(getters.getDevicesInExhibit(exhibitID).slice(0))
            } else {
                ExhibitService.getDevicesInExhibit(exhibitID)
                    .then((response) => resolve(response))
                    .catch((error) => reject(error));
            }
        });
    },

    getResourceLinesSetToExhibit: ({commit}, exhibitId) => {
        return new Promise((resolve, reject) => {
            ExhibitService.getResourceLinesSetToExhibit(exhibitId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    setResourceLineToExhibit: (context, props) => {
        return new Promise((resolve, reject) => {
            ExhibitService.setResourceLineToExhibit(props.exhibitId, props.resourceLineId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    }
};


export default {
    state, mutations, getters, actions
}
