import LabelService from "../../services/OcuService/modules/labelService";

const state = {
    labelTypes: [],
    labels: [],
};

const mutations = {
    SET_LABELTYPES(state, labelTypes) {
        state.labelTypes = labelTypes;
    },
    SET_LABEL_FOR_LABELTYPE(state, labelTypeId, labels) {
        state.labels[labelTypeId] = (labels === undefined ? [] : labels);
    }
};

const getters = {
    getLabelTypes: (state) => () => {
        return state.labelTypes;
    },

    getLabels: (state) => (labelTypeId) => {
        if (state.labels[labelTypeId] !== undefined) {
            return state.labels[labelTypeId];
        } else {
            return [];
        }
    }
};

const actions = {
    getLabelTypes: ({commit, getters}) => {
        return new Promise((resolve, reject) => {
            if (getters.getLabelTypes().length > 0) {
                resolve(getters.getLabelTypes().slice(0));
            } else {
                LabelService.getLabelTypes()
                    .then((response) => resolve(response))
                    .catch((error) => reject(error));
            }
        });
    },
    getLabels: ({commit, getters}, labelTypeId) => {
        return new Promise((resolve, reject) => {
            if (getters.getLabels(labelTypeId).length > 0) {
                resolve(getters.getLabels(labelTypeId).slice(0));
            } else {
                LabelService.getLabels(labelTypeId)
                    .then((response) => resolve(response))
                    .catch((error) => reject(error));
            }
        });
    },

    updateLabels: ({commit}, {labelId, labelData}) => {
        return new Promise((resolve, reject) => {
            LabelService.updateLabels(labelId, labelData)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    exportLabels: ({commit}, {labelId}) => {
        return new Promise((resolve, reject) => {
            LabelService.exportLabels(labelId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    importLabels: ({commit}, {labelId, labelData}) => {
        return new Promise((resolve, reject) => {
            LabelService.importLabels(labelId, labelData)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    }
};


export default {
    state, mutations, getters, actions
}
