import ModuleService from "../../services/OcuService/modules/moduleService";

const state = {
    moduleTypes: [],
    modules: []
};

const mutations = {
    SET_MODULE_TYPES(state, moduleTypes) {
        state.moduleTypes = moduleTypes;
    },

    SET_MODULES_FOR_TYPE(state, moduleObj) {
        state.modules[moduleObj.moduleTypeId] = (moduleObj.moduleData === undefined ? [] : moduleObj.moduleData);
    },

    SET_MODULE(state, moduleObj) {

    }
};

const getters = {
    getModuleTypes: (state) => () => {
        return state.moduleTypes;
    },

    getModulesForType: (state) => (moduleTypeId) => {
        if (state.modules[moduleTypeId] !== undefined) {
            return state.modules[moduleTypeId];
        } else {
            return [];
        }
    }
};

const actions = {
    getModuleTypes: ({commit, getters}) => {
        return new Promise((resolve, reject) => {
            if (getters.getModuleTypes().length > 0) {
                resolve(getters.getModuleTypes().slice(0));
            } else {
                ModuleService.getModuleTypes()
                    .then((response) => resolve(response))
                    .catch((error) => reject(error));
            }
        });
    },

    getModulesOfType: ({commit, getters}, moduleTypeId) => {
        return new Promise((resolve, reject) => {
            if(moduleTypeId===null) resolve();
            ModuleService.getModulesOfModuleType(moduleTypeId)
                .then((response) => {
                    commit('SET_MODULES_FOR_TYPE', {moduleTypeId: moduleTypeId, moduleData: response});
                    resolve(response);
                })
                .catch((error) => reject(error));
        });
    },
    getGenericModulesOfType:({commit,getters},{genericModuleType})=>{
      return new Promise((resolve,reject)=>{
            ModuleService.getGenericModulesOfType(genericModuleType)
                .then((response)=>resolve(response))
                .catch((error)=>reject(error))
      })
    },

    getModuleById: ({commit, getters}, moduleId) => {
        return new Promise((resolve, reject) => {
            ModuleService.getModuleById(moduleId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    createModule:({commit}, {moduleData})=> {
        return new Promise((resolve, reject) => {
            ModuleService.createModule( moduleData)
                .then((response) => resolve(response))
                .catch((error) =>reject(error));
        });
    },

    duplicateModule:({commit},{moduleId})=>{
      return new Promise((resolve,reject)=>{
          ModuleService.duplicateModule(moduleId)
              .then((response)=>resolve(response))
              .catch((error)=>reject(error))
      })
    },

    updateModule: ({commit}, {moduleId, moduleData})=> {
        return new Promise((resolve, reject) => {
            ModuleService.updateModule(moduleId, moduleData)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    deleteModule:({commit},{moduleId})=> {
        return new Promise((resolve, reject) => {
            ModuleService.deleteModule(moduleId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },
};


export default {
    state, mutations, getters, actions
}
