import ProjectService from "../../services/OcuService/modules/projectService";

const state = {
    projects: [],
    currentProjectLanguages: [],
};

const mutations = {
    SET_PROJECTS(state, projects) {
        state.projects = projects;
    },
    SET_PROJECT_LANGUAGES(state, languages) {
        state.currentProjectLanguages = languages;
    }
};

const getters = {
    getProjects: (state) => () => {
        return state.projects;
    },
    getCurrentProjectLanguages: (state) => () => {
        return state.currentProjectLanguages;
    },
};

const actions = {
    getAvailableProjects: ({commit, getters}) => {
        return new Promise((resolve, reject) => {
            if (getters.getProjects().length > 0) {
                resolve(getters.getProjects().slice(0));
            } else {
                ProjectService.getAvailableProjects()
                    .then((response) => resolve(response))
                    .catch((error) => reject(error));
            }
        });
    },
    getAllProjects: ({}) => {
        return new Promise((resolve, reject) => {
            ProjectService.getAllProjects()
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getProject: ({commit}, {projectId}) => {
        return new Promise((resolve, reject) => {
            ProjectService.getProject(projectId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    createProject: ({}, projectData) => {
        let dataObj = {
            name: projectData.name,
            title: projectData.title,
            location: projectData.location
        };

        return new Promise((resolve, reject) => {
            ProjectService.createProject(dataObj)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });

    },

    getCurrentProjectLanguages: ({commit, getters}) => {
        return new Promise((resolve, reject) => {
            if (getters.getCurrentProjectLanguages().length > 0) {
                resolve(getters.getCurrentProjectLanguages().slice(0));
            } else {
                ProjectService.getCurrentProjectLanguages()
                    .then((response) => {
                        commit('SET_PROJECT_LANGUAGES', response);
                        resolve(response);
                    })
                    .catch((error) => reject(error));
            }
        })
    },
    clearAndFetchCurrentProjectLanguages: ({commit}) => {
        return new Promise((resolve, reject) => {
            commit('SET_PROJECT_LANGUAGES', []);
            ProjectService.getCurrentProjectLanguages()
                .then((response) => {
                    commit('SET_PROJECT_LANGUAGES', response);
                    resolve(response);
                })
                .catch((error) => reject(error));
        })
    },

    updateProject: ({}, {projectData, projectId}) => {
        let dataObj = {
            name: projectData.name,
            title: projectData.title,
            location: projectData.location
        };

        return new Promise((resolve, reject) => {
            ProjectService.updateProject(dataObj, projectId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    addModuleTypeToProject: ({}, {projectId, moduleTypeId}) => {
        return new Promise((resolve, reject) => {
            ProjectService.addModuleTypeToProject(projectId, moduleTypeId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    deleteModuleTypeFromProject:({},{projectId,moduleTypeId})=>{
        return new Promise((resolve,reject)=>{
            ProjectService.deleteModuleTypeFromProject(projectId,moduleTypeId)
                .then((response)=>resolve(response))
                .catch((error)=>reject(error));
        });
    },

    setProjectToUser: ({}, {projectId, userId,permissions}) => {
        return new Promise((resolve, reject) => {
            ProjectService.setProjectToUser(projectId, userId,permissions)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    deleteProjectFromUser: ({},{projectId, userId}) => {
        return new Promise((resolve, reject) => {
            ProjectService.deleteProjectFromUser(projectId, userId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    }

};

export default {
    state, mutations, getters, actions
}
