import Scenario from "../../../services/OcuService/modules/scenarioService";

const state = {
    actions: [],
};

const mutations = {
    SET_ACTIONS_FOR_SCENARIO(state, scenarioActions) {
        state.actions[scenarioActions.scenarioId] = (scenarioActions.actions === undefined ? [] : scenarioActions.actions);
    },

    ADD_ACTION_FOR_SCENARIO(state, scenarioActionObj) {
        state.actions[scenarioActionObj.scenarioId].push(scenarioActionObj.action)
    },

    UPDATE_ACTION(state, obj) {
        /*TODO check if correct*/
    },

    DELETE_ACTION(state, obj) {
        state.actions[obj.scenarioId] = state.actions[obj.scenarioId].filter(x => x.id !== obj.actionId);
    }

};

const getters = {
    getActionsByScenarioId: (state) => (scenarioId) => {
        return (state.actions[scenarioId] === undefined ? [] : state.actions[scenarioId]);
    }
};

const actions = {
    getScenarioActions: ({commit, getters}, scenarioId) => {
        return new Promise((resolve, reject) => {
            if (getters.getActionsByScenarioId(scenarioId).length > 0) {
                resolve(getters.getActionsByScenarioId(scenarioId).slice(0))
            } else {
                Scenario.getScenarioActions(scenarioId)
                    .then((response) => resolve(response))
                    .catch((error) => reject(error));
            }

        });
    },
    getAction: ({commit}, actionId) => {
        return new Promise((resolve, reject) => {
            Scenario.getScenarioActionById(actionId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    createAction: ({commit}, actionData) => {
        let dataObj = {
            name: actionData.name,
            startPosition: actionData.startPosition,
            hold: actionData.hold,
            duration: actionData.duration,
            fadeIn: actionData.fadeIn,
            fadeOut: actionData.fadeOut,
            scenarioId: actionData.scenarioId,
            triggerId: actionData.triggerId || null,
            description:actionData.description||"",
            enabled:actionData.enabled||false,
        };
        return new Promise((resolve, reject) => {
            Scenario.createAction(dataObj)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    updateAction: ({commit}, {actionData, actionId}) => {
        let dataObj = {
            name: actionData.name,
            startPosition: actionData.startPosition,
            hold: actionData.hold,
            duration: actionData.duration,
            fadeIn: actionData.fadeIn,
            fadeOut: actionData.fadeOut,
            scenarioId: actionData.scenarioId,
            triggerId: actionData.triggerId || null,
            description:actionData.description||"",
            enabled:actionData.enabled||false,
        };


        return new Promise((resolve, reject) => {
            Scenario.updateAction(dataObj, actionId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });

    },

    deleteAction: ({commit}, {actionId}) => {
        return new Promise((resolve, reject) => {
            Scenario.deleteAction(actionId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getDeploymentsOfAction: ({commit},actionId) => {
        return new Promise((resolve,reject)=>{
            Scenario.getActionDeplopyments(actionId)
                .then((response)=>resolve(response))
                .catch((error)=>reject(error));
        });
    }
};

export default {
    state, mutations, getters, actions,
}
