import ScenarioService from "../../../services/OcuService/modules/scenarioService";

const state = {
    scenarios: [],
    scenarioActions: [],
    scenarioTriggers: [],
};
const mutations = {
    SET_SCENARIOS(state, scenarios) {
        state.scenarios = scenarios;
    },
    SET_SCENARIO_ACTIONS(state, scenarioId, scenarioActions) {
        state.scenarioActions[scenarioId] = (scenarioActions === undefined ? [] : scenarioActions);
    },
    SET_SCENARIO_TRIGGERS(state, scenarioId, scenarioTriggers) {
        state.scenarioTriggers[scenarioId] = (scenarioTriggers === undefined ? [] : scenarioTriggers);
    }
};
const getters = {
    getScenarios: (state) => () => {
        return state.scenarios;
    }
};
const actions = {
    getScenarios: ({commit, getters}) => {
        return new Promise((resolve, reject) => {
            if (getters.getScenarios().length > 0) {
                resolve(getters.getScenarios().slice(0));
            } else {
                ScenarioService.getScenarios()
                    .then((response) => resolve(response))
                    .catch((error) => reject(error));
            }
        });
    },

    getScenario: ({commit}, scenarioId) => {
        return new Promise((resolve, reject) => {
            ScenarioService.getScenarioById(scenarioId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    createScenario: ({commit}, {scenarioData}) => {
        let dataObj = {
            name: scenarioData.name,
            precision: scenarioData.precision,
            projectId: scenarioData.projectId,
            exhibitId: scenarioData.exhibitId,
            themeId: scenarioData.themeId,
        };

        return new Promise((resolve, reject) => {
            ScenarioService.createScenario(dataObj)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    updateScenario: ({commit}, {scenarioData, scenarioId}) => {
        let dataObj = {
            name: scenarioData.name,
            precision: scenarioData.precision,
            projectId: scenarioData.projectId,
            exhibitId: scenarioData.exhibitId,
            themeId: scenarioData.themeId,
        };


        return new Promise((resolve, reject) => {
            ScenarioService.updateScenario(dataObj, scenarioId)
                .then((response) => resolve(response))
                .catch((error) => reject(error))
        })
    },

    deleteScenario: ({commit}, {scenarioId}) => {
        return new Promise((resolve, reject) => {
            ScenarioService.deleteScenario(scenarioId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    duplicateScenario: ({commit}, {scenarioId}) => {
        return new Promise((resolve, reject) => {
            ScenarioService.duplicateScenario(scenarioId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    setLanguagesOfScenario: ({commit}, {scenarioId, scenarioLanguages}) => {
        return new Promise((resolve, reject) => {
            ScenarioService.setLanguagesOfScenario(scenarioId, {languages: scenarioLanguages})
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    setDefaultScenarioToProject: ({commit}, {scenarioId}) => {
        return new Promise((resolve, reject) => {
            ScenarioService.setDefaultScenarioToProject(scenarioId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getScenarioClientData: ({}, {clientId}) => {
        return new Promise((resolve, reject) => {
            ScenarioService.getScenarioClientData(clientId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getScenarioClientReadOnlyData: ({}, {exhibitId}) => {
        return new Promise((resolve, reject) => {
            ScenarioService.getScenarioClientReadOnlyData(exhibitId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    getScenarioClientDashboardData: ({}, {exhibitId}) => {
        return new Promise((resolve, reject) => {
            ScenarioService.getScenarioClientDashboardData(exhibitId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    }

};


export default {
    state, mutations, getters, actions
}
