import Scenario from "../../../services/OcuService/modules/scenarioService";


const state = {
    triggers: [],
};

const mutations = {
    SET_TRIGGERS_FOR_SCENARIO(state, obj) {
        state.triggers[obj.scenarioId] = (obj.triggers === undefined ? [] : obj.triggers);
    },

    ADD_TRIGGER_FOR_SCENARIO(state, obj) {
        state.triggers[obj.scenarioId].push(obj.triggerData);
    },

    UPDATE_TRIGGER_FOR_SCENARIO(state, obj) {
        let index = state.triggers[obj.scenarioId].findIndex(x => x.id === obj.triggerId);
        state.triggers[obj.scenarioId][index] = obj.triggerData;
    },

    DELETE_TRIGGER_IN_SCENARIO(state, obj) {
        state.triggers[obj.scenarioId] = state.triggers[obj.scenarioId].filter(x => x.id !== obj.triggerId);
    },
};

const getters = {
    getTriggersByScenarioId: (state) => (scenarioId) => {
        return (state.triggers[scenarioId] === undefined ? [] : state.triggers[scenarioId]);
    },
    getTriggerById: (state) => (scenarioId, triggerId) => {

    }
};

const actions = {
    getScenarioTriggers: ({commit, getters}, scenarioId) => {
        return new Promise((resolve, reject) => {
            if (getters.getTriggersByScenarioId(scenarioId).length > 0) {
                resolve(getters.getTriggersByScenarioId(scenarioId).slice(0));
            } else {
                Scenario.getScenarioTriggers(scenarioId)
                    .then((response) => resolve(response))
                    .catch((error) => reject(error));
            }
        });
    },

    getTrigger: ({},{triggerId}) => {
        return new Promise((resolve, reject) => {
            Scenario.getScenarioTriggerById(triggerId)
                    .then((response) => resolve(response))
                    .catch((error) => reject(error));
        });
    },

    createTrigger: ({commit}, triggerData) => {
        let dataObj = {
            name: triggerData.name,
            startPosition: triggerData.startPosition,
            duration: triggerData.duration,
            repeat: triggerData.repeat,
            value: triggerData.value,
            scenarioId: triggerData.scenarioId,
            deviceId: triggerData.deviceId,
        };

        return new Promise((resolve, reject) => {
            Scenario.createTrigger(dataObj)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });

    },

    updateTrigger: ({commit}, triggerData) => {
        let dataObj = {
            name: triggerData.name,
            startPosition: triggerData.startPosition,
            duration: triggerData.duration,
            repeat: triggerData.repeat,
            value: triggerData.value,
            scenarioId: triggerData.scenarioId,
            deviceId: triggerData.deviceId,
        };

        return new Promise((resolve, reject) => {
            Scenario.updateTrigger(dataObj, triggerData.triggerId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    },

    deleteTrigger: ({commit}, {triggerId}) => {
        return new Promise((resolve, reject) => {
            Scenario.deleteTrigger(triggerId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });

    },

    getActionsOfTriggers: ({},triggerId) => {
        return new Promise((resolve, reject) => {
            Scenario.getActionsOfTrigger(triggerId)
                .then((response) => resolve(response))
                .catch((error) => reject(error));
        });
    }
};

export default {
    state, mutations, getters, actions
}
