import UserService from "../../services/OcuService/modules/userService";

const state = {
    authUser: null,
    users: []
};

const mutations = {
    SET_USER(state, userObj) {
        state.authUser = userObj;
        UserService.setToken(userObj.access_token);
        UserService.setLanguage(window.env.LANGUAGE);
    },
    SET_USERS(state, users) {
        state.users = users;
    },
    CLEAR_USER(state) {
        // state.authUser = null
        state.authUser = null;
    },
    CLEAR_USERS(state) {
        state.users = [];
    }
};

const getters = {
    getActiveUser: state => () => {
        return state.authUser;
    },
    getUsers: state => () => {
        return state.users;
    }
};

const actions = {
    loginUser: (context, userCredentials) => {
        const userObject = {
            grant_type: "password",
            username: userCredentials.email,
            password: userCredentials.password,
            scope: "*",
            client_id: userCredentials.clientID || window.env.CLIENTID,
            client_secret:
                userCredentials.clientSecret || window.env.CLIENTSECRET
        };

        return new Promise((resolve, reject) => {
            UserService.loginUser(userObject)
                .then(response => {
                    const authUser = {};
                    authUser.access_token = response.access_token;
                    authUser.refresh_token = response.refresh_token;
                    UserService.setToken(response.access_token);
                    UserService.getUser().then(function(response) {
                        /*Add To local storage*/
                        authUser.name = response.data.name;
                        authUser.id = response.data.id;
                        authUser.email = response.data.email;
                        authUser.rights = response.data.rights;
                        authUser.role = response.data.role;
                        authUser.roleKey = response.data.roleKey;
                        authUser.language = response.data.language;
                        window.localStorage.setItem(
                            window.env.LOCALSTORAGETAG,
                            JSON.stringify(authUser)
                        );
                        return resolve(authUser);
                    });
                })
                .catch(error => {
                    console.warn(error);
                    return reject(error);
                });
        });
    },

    getUsers: ({ commit, getters }) => {
        return new Promise((resolve, reject) => {
            const users = getters.getUsers();
            if (users.length > 0) {
                resolve(Object.assign({}, users));
            } else {
                UserService.getUsers()
                    .then(response => {
                        // commit('SET_USERS', response);
                        resolve(response);
                    })
                    .catch(error => {
                        reject(error);
                    });
            }
        });
    },

    createUser: (context, user) => {
        return new Promise((resolve, reject) => {
            UserService.createUser(user)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    getUser: ({ commit, getters }, userid) => {
        return new Promise((resolve, reject) => {
            UserService.getUser(userid)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    getAllUsers: ({}) => {
        return new Promise((resolve, reject) => {
            UserService.getAllUsers()
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    updateUser: (context, { id, data }) => {
        return new Promise((resolve, reject) => {
            UserService.updateUser(id, data)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    deleteUser: (context, userID) => {
        return new Promise((resolve, reject) => {
            UserService.deleteUser(userID)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    getCurrentUser: () => {
        return new Promise((resolve, reject) => {
            UserService.getUser()
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    setLastLoggedInAtProperty: () => {
        return new Promise((resolve, reject) => {
            UserService.setLastLoggedInAtProperty()
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    setUserObject: (context, userObj) => {
        context.commit("SET_USER", userObj);
    },

    clearAuthUser: context => {
        window.localStorage.removeItem(window.env.LOCALSTORAGETAG);
        window.localStorage.removeItem('lastMessage');
        context.commit("CLEAR_USER");
    },

    clearUsers: context => {
        context.commit("CLEAR_USERS");
    },

    getActionRights: ({ commit }) => {
        //@TODO: get rights of logged in user
        return new Promise((resolve, reject) => {
            state.authUser
                ? resolve(state.authUser.role)
                : reject("no role defined");
        });
    },

    getRoles: () => {
        return new Promise((resolve, reject) => {
            UserService.getRoles()
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    getLastExport: () => {
        return new Promise((resolve, reject) => {
            UserService.getLastExport()
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    setRoleToUser: (context, props) => {
        return new Promise((resolve, reject) => {
            UserService.setRoleToUser(props.roleId, props.userId)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    resetUserPassword: ({}, email) => {
        return new Promise((resolve, reject) => {
            UserService.resetUserPassword(email)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    getUserAnalytics: ({}, params) => {
        return new Promise((resolve, reject) => {
            UserService.getUserAnalytics(params)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });
    },

    updateUserPassword: ({}, data) => {
        return new Promise((resolve, reject) => {
            UserService.updateUserPassword(data)
                .then(response => resolve(response))
                .catch(error => reject(error));
        });

    }
};

export default {
    state,
    actions,
    mutations,
    getters
};
