describe('Customer visits API Test', () => {
    it('Get all customer visits', () => {
        cy.vuex().invoke('dispatch', 'getCustomerVisits')
            .should((response) => {
                assert.typeOf(response, 'object', 'response should be object');
            });
    });

    it('Create customer visit', () => {
        let newCustomerVisit = {
            date: "2020-11-17",
            time: "00:00",
            firstName: "Bert",
            lastName: "Huys",
            email: "bert.huys@ocular.be",
            phone: "123",
            language: "nl",
            preferenceHouse: 0,
            preferenceStyle: 0,
            memo: "test"
        };

        cy.vuex().invoke('dispatch', 'createCustomerVisit', newCustomerVisit)
            .should((response) => {
                assert.typeOf(response, 'object', 'response should be object');
                expect(response.data.time).to.equal(newCustomerVisit.time);
                expect(response.data.date).to.equal(newCustomerVisit.date);
                expect(response.data.customer.firstName).to.equal(newCustomerVisit.firstName);
                expect(response.data.customer.lastName).to.equal(newCustomerVisit.lastName);
                expect(response.data.customer.archived).to.be.false;
                expect(response.data.acceptedBy).to.be.null;
                expect(response.data.visited).to.be.null;
            });
    });

    it('Update created customer visit', () => {
        const updateCustomerVisit = {
            customerVisitId: 1,
            customerVisitData: {
                date: "17-11-2020",
                time: "12:00",
                firstName: "Bert",
                lastName: "Huys",
                email: "bert.huys@ocular.be",
                phone: "123",
                language: "nl",
                preferenceHouse: 0,
                preferenceStyle: 0,
                memo: "test lalala",
                ambienceId: null,
                selectionId: null
            }
        };

        cy.vuex().invoke('dispatch', 'updateCustomerVisit', updateCustomerVisit)
            .should((response) => {
                assert.typeOf(response, 'object', 'response should be object');
                expect(response.data.time).to.equal(updateCustomerVisit.customerVisitData.time);
                expect(response.data.customer.firstName).to.equal(updateCustomerVisit.customerVisitData.firstName);
                expect(response.data.customer.lastName).to.equal(updateCustomerVisit.customerVisitData.lastName);
                expect(response.data.customer.memo).to.equal(updateCustomerVisit.customerVisitData.memo);
            });
    });

    it('Accept created customer visit', () => {
        const id = 1;
        cy.vuex().invoke('dispatch', 'acceptCustomerVisit', id)
            .should((response) => {
                assert.typeOf(response, 'object', 'response should be object');
                expect(response.data.id).to.equal(id);
                expect(response.data.acceptedBy).not.to.be.null;
            });
    });

    it('Refuse created customer visit', () => {
        const id = 1;
        cy.vuex().invoke('dispatch', 'refuseCustomerVisit', id)
            .should((response) => {
                assert.typeOf(response, 'object', 'response should be object');
                expect(response.data.id).to.equal(id);
                expect(response.data.acceptedBy).to.be.null;
            });
    });

    it('Activate created customer visit', () => {
        const id = 1;
        cy.vuex().invoke('dispatch', 'activateCustomerVisit', id)
            .should((response) => {
                assert.typeOf(response, 'object', 'response should be object');
                expect(response.data.id).to.equal(id);
            });
    });

    it('Get active customer visit', () => {
        const id = 1;
        cy.vuex().invoke('dispatch', 'getActiveCustomerVisit')
            .should((response) => {
                assert.typeOf(response, 'object', 'response should be object');
                expect(response.data.id).to.equal(id);
            });
    });

    it('Get created customer visit', () => {
        const id = 1;
        cy.vuex().invoke('dispatch', 'getCustomerVisit', id)
            .should((response) => {
                assert.typeOf(response, 'object', 'response should be object');
                expect(response.data.id).to.equal(id);
            });
    });

    it('Get created customer visit offers', () => {
        const id = 1;
        cy.vuex().invoke('dispatch', 'getCustomerVisitOffers', id)
            .should((response) => {
                assert.typeOf(response, 'object', 'response should be object');
                expect(response.data.length).to.equal(0);
            });
    });

    it('Archive (delete) created customer visit', () => {
        const id = 1;
        cy.vuex().invoke('dispatch', 'deleteCustomerVisit', id)
            .should((response) => {
                assert.typeOf(response, 'object', 'response should be object');
                expect(response.response).to.equal("success");
            });
    });

    it('Get customer visit archive', () => {
        cy.vuex().invoke('dispatch', 'getCustomerVisitArchive')
            .should((response) => {
                assert.typeOf(response, 'object', 'response should be object');
                expect(response.data[0].id).to.equal(1);
            });
    });

});
